PySensors3
----------
Python3 bindings to libsensors (via ctypes)

.. image:: https://img.shields.io/pypi/pyversions/pysensors3.svg
   :target: https://pypi.python.org/pypi/pysensors3

.. image:: https://img.shields.io/pypi/v/pysensors3.svg
   :target: https://pypi.python.org/pypi/pysensors3

.. image:: https://img.shields.io/maintenance/yes/2019.svg?maxAge=2592000

Hard fork of https://bitbucket.org/blackjack/pysensors/. See `doc/OLD_README.rst` for original documentation.

Original license (LGPL 2+) retained for this derivative work.
